# Release notes for MUSE v1.5.2 (August 27, 2025)

This release has some small bug fixes:

- {github}`791`: Fixed a bug that was affecting the LCOE and EAC output files, occasionally giving incorrect values. Any simulations using these files should be re-run using this updated version.
- {github}`788`: Fixed a bug that in some cases would allow technologies that should be prohibited by an agent's filters to be selected for investment.
